@@ -5,6 +5,4 @@ urlpatterns = patterns('desktopnotifications.views',
     url(r'^get/(\d+)/?$', 'get_notification'),
     url(r'^get_tags/?$', 'get_tags'),
     url(r'^is_authenticated/?$', 'check_is_authenticated'),
-) + patterns('',
-    url(r'^login/$', 'django.contrib.auth.views.login', {'template_name': 'login_notification.html'}),
-)
\ No newline at end of file
+)
